@@ -7,8 +7,12 @@
 #ifndef __AUTOAWAY_H__
 #define __AUTOAWAY_H__
 
-#include "common.h"
+#include <glib.h>
 
-guint auto_away( void );
+extern gint autoaway_timeout_tag;
+extern gchar *auto_away_message;
+extern gchar *auto_na_message;
+
+guint auto_away (void);
 
 #endif /* __AUTOAWAY_H__ */
