@@ -41,7 +41,7 @@ extern datum icudb_fetch (DB_FILE file, datum key);
 
 #endif
 
-#if defined(HAVE_LIBGDBM) || defined(HAVE_NDMB)
+#if (defined(HAVE_LIBGDBM) || defined(HAVE_NDMB))
 #define HAVE_ICUDB
 #define DB_READ	 0
 #define DB_WRITE 1
@@ -55,6 +55,7 @@ extern datum icudb_fetch (DB_FILE file, datum key);
 extern DB_FILE icudb_open (gchar *db_path, gint mode);
 extern int icudb_close_all (void);
 extern int icudb_close (DB_FILE file);
+extern int icudb_close_dbpath (gchar *db_path );
 #endif
 
 #endif
